Learn R Programming

MSBVAR (version 0.1.1)

reduced.form.var: Estimation of a reduced form VAR model

Description

Estimates a reduced form VAR using equation-by-equation seemingly unrelated regression (SUR).

Usage

reduced.form.var(dat, p, z=NULL)

Arguments

Value

List with elements,intercept{Row vector of the m intercepts}ar.coefs{ M x M X P array of the AR coefficients. The first M X M array is for lag 1, the p'th array for lag p.}Bhat{ (M*P + dim(z)[2]) x M matrix of the coefficients, where the columns correspond to the variables in the VAR}exog.coefs{ dim(z)[2] x M matrix of exogenous coefficients, or NA if z=NULL}vcv{ M x M matrix of the maximum likelihood estimate of the residual covariance}mean.S{M x M matrix of the posterior residual covariance.}hstar{(M*P) x M right hand side variables crossproduct.}X{Right hand side variables for the estimation of BVAR}Y{Left hand side variables for the estimation of BVAR}y{Input data (dat)}

Details

Frequentist VAR estimation. This is a workhorse function --- you will want to use other functions to report and interpret the results of this object.

References

Sims, C.A. 1980. "Macroeconomics and Reality" Econometrica 48(1): 1-48.

See Also

See Also szbvar for Bayesian estimation.

Examples

Run this code
data(IsraelPalestineConflict)
rf.var <- reduced.form.var(IsraelPalestineConflict, p=6)
plot(irf.var(rf.var, nsteps=12))

Run the code above in your browser using DataLab