gibbs.msbsvar(x, N1 = 1000, N2 = 1000,
tune = matrix(10, x$m, x$h))mcmc class object of N2 draws of
bmcmc class object of N2 draws of the
coefficients for the F matrix for the AR dynamics.mcmc class object of N2 draws for
the $m \times h$ values of $\xi$mcmc class object for the N2 draws of
the $h \times h$ matrix QN2 of bit class
objects that store the samples of the 0-1 matrices for the
h-1 data for the state-space. These objects can be accessed
and summarized using the sum.SS,
mean.SS and plot.SS function class.mh vector of the acceptance rates for the
Metropolis steps for each equation in each regimemsbsvar, so consult that
function for further information. The function returns N2
draws of the parameters from the sampler.Much of the computational heavy lifting (especially the state-space sampling for the $T \times h$ regime values) is done in compiled C++ code. Consult the course code for additional details.
This function is experimental, so use at your own risk.
msbsvar, sum.SS,
mean.SS, plot.SS, mcmc