mcmc.szbsvar: Gibbs sampler for coefficients of a B-SVAR model
Description
Draws a posterior sample of the reduced form coefficients for a
Bayesian SVAR model
Usage
mcmc.szbsvar(varobj, A0.posterior)
Arguments
Value
A list of the class "mcmc.bsvar.posterior" with the following components:A0.posterior$m \times m \times N2$ array of
the posterior matrices $A_0$.B.sample$N2 \times ncoef$ matrix of the
reduced form coefficients for the SVAR.
Details
This function draws the parameters from the Bayesian SVAR model
described by Waggoner and Zha (2003). The details can be found in
szbsvar. The draws are done for the SVAR
model and then translated into the reduced form parameters.
References
Waggoner, Daniel F. and Tao A. Zha. 2003. "A Gibbs sampler for
structural vector autoregressions" Journal of Economic Dynamics
& Control. 28:349--366.